==> information-system-model-7.0.0-20230516.144426-16-sources.jar: org/gcube/informationsystem/model/impl/properties/PropagationConstraintImpl.java <==
/**
 * 
 */
package org.gcube.informationsystem.model.impl.properties;

import org.gcube.com.fasterxml.jackson.annotation.JsonFormat;
import org.gcube.com.fasterxml.jackson.annotation.JsonProperty;
import org.gcube.com.fasterxml.jackson.annotation.JsonTypeName;
import org.gcube.informationsystem.model.reference.properties.PropagationConstraint;

/**
 * @author Luca Frosini (ISTI - CNR)
 */
@JsonTypeName(value=PropagationConstraint.NAME)
public final class PropagationConstraintImpl extends PropertyImpl implements PropagationConstraint {

	/**
	 * Generated Serial Version UID
	 */
	private static final long serialVersionUID = -4708881022038107688L;

	@JsonFormat(shape=JsonFormat.Shape.STRING)
	@JsonProperty(value=ADD_PROPERTY)
	protected AddConstraint addConstraint;
	
	@JsonFormat(shape=JsonFormat.Shape.STRING)
	@JsonProperty(value=DELETE_PROPERTY)
	protected DeleteConstraint deleteConstraint;
	
	@JsonFormat(shape=JsonFormat.Shape.STRING)
	@JsonProperty(value=REMOVE_PROPERTY)
	protected RemoveConstraint removeConstraint;
	
	public PropagationConstraintImpl(){
		super();
	}

	@Override
	public AddConstraint getAddConstraint() {
		return this.addConstraint;
	}

	@Override
	public void setAddConstraint(AddConstraint addConstraint) {
		this.addConstraint = addConstraint;
	}
	
	@Override
	public DeleteConstraint getDeleteConstraint() {
		return this.deleteConstraint;
	}

	@Override
	public void setDeleteConstraint(DeleteConstraint deleteConstraint) {
		this.deleteConstraint = deleteConstraint;
	}
	
	@Override
	public RemoveConstraint getRemoveConstraint() {
		return this.removeConstraint;
	}

	@Override
	public void setRemoveConstraint(RemoveConstraint removeConstraint) {
		this.removeConstraint = removeConstraint;
	}

}

==> information-system-model-7.1.0-20260205.150419-54-sources.jar: org/gcube/informationsystem/model/impl/properties/PropagationConstraintImpl.java <==
/**
 * 
 */
package org.gcube.informationsystem.model.impl.properties;



import org.gcube.com.fasterxml.jackson.annotation.JsonFormat;
import org.gcube.com.fasterxml.jackson.annotation.JsonProperty;
import org.gcube.com.fasterxml.jackson.annotation.JsonTypeName;
import org.gcube.informationsystem.model.reference.properties.PropagationConstraint;

/**
 * The default implementation of the {@link PropagationConstraint} interface.
 *
 * @author Luca Frosini (ISTI - CNR)
 */
@JsonTypeName(value=PropagationConstraint.NAME)
public final class PropagationConstraintImpl extends PropertyImpl implements PropagationConstraint {

	/**
	 * The serial version UID.
	 */
	private static final long serialVersionUID = -4708881022038107688L;

	/** The add constraint. */
	@JsonFormat(shape=JsonFormat.Shape.STRING)
	@JsonProperty(value=ADD_PROPERTY)
	protected AddConstraint addConstraint;
	
	/** The delete constraint. */
	@JsonFormat(shape=JsonFormat.Shape.STRING)
	@JsonProperty(value=DELETE_PROPERTY)
	protected DeleteConstraint deleteConstraint;
	
	/** The remove constraint. */
	@JsonFormat(shape=JsonFormat.Shape.STRING)
	@JsonProperty(value=REMOVE_PROPERTY)
	protected RemoveConstraint removeConstraint;
	
	/**
	 * Default constructor.
	 */
	public PropagationConstraintImpl(){
		super();
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public AddConstraint getAddConstraint() {
		return this.addConstraint;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public void setAddConstraint(AddConstraint addConstraint) {
		this.addConstraint = addConstraint;
	}
	
	/**
	 * {@inheritDoc}
	 */
	@Override
	public DeleteConstraint getDeleteConstraint() {
		return this.deleteConstraint;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public void setDeleteConstraint(DeleteConstraint deleteConstraint) {
		this.deleteConstraint = deleteConstraint;
	}
	
	/**
	 * {@inheritDoc}
	 */
	@Override
	public RemoveConstraint getRemoveConstraint() {
		return this.removeConstraint;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public void setRemoveConstraint(RemoveConstraint removeConstraint) {
		this.removeConstraint = removeConstraint;
	}

}
